# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class OrganizationMarketingQuestions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'size': 'CompanySize',
        'workload': 'str',
        'tech_stack': 'str',
        'source': 'str'
    }

    attribute_map = {
        'size': 'size',
        'workload': 'workload',
        'tech_stack': 'tech_stack',
        'source': 'source'
    }

    def __init__(self, size=None, workload=None, tech_stack=None, source=None, local_vars_configuration=None):  # noqa: E501
        """OrganizationMarketingQuestions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._size = None
        self._workload = None
        self._tech_stack = None
        self._source = None
        self.discriminator = None

        if size is not None:
            self.size = size
        if workload is not None:
            self.workload = workload
        if tech_stack is not None:
            self.tech_stack = tech_stack
        if source is not None:
            self.source = source

    @property
    def size(self):
        """Gets the size of this OrganizationMarketingQuestions.  # noqa: E501


        :return: The size of this OrganizationMarketingQuestions.  # noqa: E501
        :rtype: CompanySize
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this OrganizationMarketingQuestions.


        :param size: The size of this OrganizationMarketingQuestions.  # noqa: E501
        :type: CompanySize
        """

        self._size = size

    @property
    def workload(self):
        """Gets the workload of this OrganizationMarketingQuestions.  # noqa: E501


        :return: The workload of this OrganizationMarketingQuestions.  # noqa: E501
        :rtype: str
        """
        return self._workload

    @workload.setter
    def workload(self, workload):
        """Sets the workload of this OrganizationMarketingQuestions.


        :param workload: The workload of this OrganizationMarketingQuestions.  # noqa: E501
        :type: str
        """

        self._workload = workload

    @property
    def tech_stack(self):
        """Gets the tech_stack of this OrganizationMarketingQuestions.  # noqa: E501


        :return: The tech_stack of this OrganizationMarketingQuestions.  # noqa: E501
        :rtype: str
        """
        return self._tech_stack

    @tech_stack.setter
    def tech_stack(self, tech_stack):
        """Sets the tech_stack of this OrganizationMarketingQuestions.


        :param tech_stack: The tech_stack of this OrganizationMarketingQuestions.  # noqa: E501
        :type: str
        """

        self._tech_stack = tech_stack

    @property
    def source(self):
        """Gets the source of this OrganizationMarketingQuestions.  # noqa: E501


        :return: The source of this OrganizationMarketingQuestions.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this OrganizationMarketingQuestions.


        :param source: The source of this OrganizationMarketingQuestions.  # noqa: E501
        :type: str
        """

        self._source = source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrganizationMarketingQuestions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrganizationMarketingQuestions):
            return True

        return self.to_dict() != other.to_dict()
